# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from .string_or_number import StringOrNumber
import typing_extensions
from ...base_types.types.custom_field_value import CustomFieldValue
from ...core.serialization import FieldMetadata
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ResolutionAttributes(UniversalBaseModel):
    identifier: typing.Optional[typing.List[StringOrNumber]] = None
    name: typing.Optional[typing.List[str]] = None
    country: typing.Optional[typing.List[str]] = None
    address: typing.Optional[typing.List[str]] = None
    date_of_birth: typing.Optional[typing.List[str]] = None
    contact: typing.Optional[typing.List[StringOrNumber]] = None
    type: typing.Optional[typing.List[str]] = None
    city: typing.Optional[typing.List[str]] = None
    state: typing.Optional[typing.List[str]] = None
    custom_field_name: typing_extensions.Annotated[
        typing.Optional[CustomFieldValue], FieldMetadata(alias="custom_{field name}")
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from .types import (
    Address,
    AttributeType,
    AttributeTypesResponse,
    AttributeValues,
    BusinessPurpose,
    CaseStatus,
    CountType,
    CreateResolvedProjectEntityRequest,
    FacetBucket,
    FacetsResponse,
    Location,
    MatchResult,
    MatchStrengthEnum,
    MatchedAttributes,
    ProductBucket,
    ProductCount,
    ProductMapping,
    ProjectEntitiesResponse,
    ProjectEntityExistsResponseData,
    ProjectEntityIdResponse,
    ProjectEntityMatchResponse,
    ProjectEntityResponse,
    ProjectEntitySupplyChainSummaryResponse,
    ProjectEntitySupplyChainSummaryResponseData,
    ProjectEntitySupplyChainUpstream,
    ProjectRiskFactor,
    ResolutionAttributes,
    ResolutionProfile,
    RiskCategoriesSummary,
    SaveProjectEntityBody,
    SingleProjectEntityResponse,
    SourceField,
    SpecialFacetBucket,
    SpecialFacetsResponse,
    StringOrNumber,
    TagResponse,
    TradeCounts,
    Translation,
    UpdateEntityTagsResponse,
    UpdateProjectEntityTagsBody,
    UpstreamCount,
    UpstreamInfo,
)

__all__ = [
    "Address",
    "AttributeType",
    "AttributeTypesResponse",
    "AttributeValues",
    "BusinessPurpose",
    "CaseStatus",
    "CountType",
    "CreateResolvedProjectEntityRequest",
    "FacetBucket",
    "FacetsResponse",
    "Location",
    "MatchResult",
    "MatchStrengthEnum",
    "MatchedAttributes",
    "ProductBucket",
    "ProductCount",
    "ProductMapping",
    "ProjectEntitiesResponse",
    "ProjectEntityExistsResponseData",
    "ProjectEntityIdResponse",
    "ProjectEntityMatchResponse",
    "ProjectEntityResponse",
    "ProjectEntitySupplyChainSummaryResponse",
    "ProjectEntitySupplyChainSummaryResponseData",
    "ProjectEntitySupplyChainUpstream",
    "ProjectRiskFactor",
    "ResolutionAttributes",
    "ResolutionProfile",
    "RiskCategoriesSummary",
    "SaveProjectEntityBody",
    "SingleProjectEntityResponse",
    "SourceField",
    "SpecialFacetBucket",
    "SpecialFacetsResponse",
    "StringOrNumber",
    "TagResponse",
    "TradeCounts",
    "Translation",
    "UpdateEntityTagsResponse",
    "UpdateProjectEntityTagsBody",
    "UpstreamCount",
    "UpstreamInfo",
]



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
from ...generated_types.types.entities import Entities
import typing
from ...generated_types.types.attributes import Attributes
from ...generated_types.types.relationships import Relationships
from .ontology_entity_type_field import OntologyEntityTypeField
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class OntologyEntityType(UniversalBaseModel):
    id: Entities
    label: str
    comment: str
    attribute: typing.List[Attributes]
    relationship: typing.List[Relationships]
    field: typing.List[OntologyEntityTypeField]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
from .ontology_base_filters import OntologyBaseFilters
import typing
from .ontology_region import OntologyRegion
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class GetOntologyRegionsResponse(UniversalBaseModel):
    """
    Examples
    --------
    from sayari.ontology import (
        GetOntologyRegionsResponse,
        OntologyBaseFilters,
        OntologyRegion,
    )

    GetOntologyRegionsResponse(
        filters=OntologyBaseFilters(
            id=["usa_&_canada"],
        ),
        data=[
            OntologyRegion(
                id="usa_&_canada",
                label="Usa & Canada",
            )
        ],
        total_count=1234,
    )
    """

    filters: OntologyBaseFilters
    data: typing.List[OntologyRegion]
    total_count: int

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from .match_strength_enum import MatchStrengthEnum
from .attribute_values import AttributeValues
from .product_mapping import ProductMapping
from .project_entity_match_response import ProjectEntityMatchResponse
from .tag_response import TagResponse
from .case_status import CaseStatus
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ProjectEntityResponse(UniversalBaseModel):
    project_entity_id: str
    project_id: str
    label: str
    upload_ids: typing.List[str]
    strength: MatchStrengthEnum
    created_at: str
    attributes: typing.Dict[str, AttributeValues]
    product_mapping: typing.Optional[ProductMapping] = None
    matches: typing.List[ProjectEntityMatchResponse]
    tags: typing.List[TagResponse]
    case: typing.Optional[CaseStatus] = None
    updated_at: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from .address import Address
from .attribute_type import AttributeType
from .attribute_types_response import AttributeTypesResponse
from .attribute_values import AttributeValues
from .business_purpose import BusinessPurpose
from .case_status import CaseStatus
from .count_type import CountType
from .create_resolved_project_entity_request import CreateResolvedProjectEntityRequest
from .facet_bucket import FacetBucket
from .facets_response import FacetsResponse
from .location import Location
from .match_result import MatchResult
from .match_strength_enum import MatchStrengthEnum
from .matched_attributes import MatchedAttributes
from .product_bucket import ProductBucket
from .product_count import ProductCount
from .product_mapping import ProductMapping
from .project_entities_response import ProjectEntitiesResponse
from .project_entity_exists_response_data import ProjectEntityExistsResponseData
from .project_entity_id_response import ProjectEntityIdResponse
from .project_entity_match_response import ProjectEntityMatchResponse
from .project_entity_response import ProjectEntityResponse
from .project_entity_supply_chain_summary_response import ProjectEntitySupplyChainSummaryResponse
from .project_entity_supply_chain_summary_response_data import ProjectEntitySupplyChainSummaryResponseData
from .project_entity_supply_chain_upstream import ProjectEntitySupplyChainUpstream
from .project_risk_factor import ProjectRiskFactor
from .resolution_attributes import ResolutionAttributes
from .resolution_profile import ResolutionProfile
from .risk_categories_summary import RiskCategoriesSummary
from .save_project_entity_body import SaveProjectEntityBody
from .single_project_entity_response import SingleProjectEntityResponse
from .source_field import SourceField
from .special_facet_bucket import SpecialFacetBucket
from .special_facets_response import SpecialFacetsResponse
from .string_or_number import StringOrNumber
from .tag_response import TagResponse
from .trade_counts import TradeCounts
from .translation import Translation
from .update_entity_tags_response import UpdateEntityTagsResponse
from .update_project_entity_tags_body import UpdateProjectEntityTagsBody
from .upstream_count import UpstreamCount
from .upstream_info import UpstreamInfo

__all__ = [
    "Address",
    "AttributeType",
    "AttributeTypesResponse",
    "AttributeValues",
    "BusinessPurpose",
    "CaseStatus",
    "CountType",
    "CreateResolvedProjectEntityRequest",
    "FacetBucket",
    "FacetsResponse",
    "Location",
    "MatchResult",
    "MatchStrengthEnum",
    "MatchedAttributes",
    "ProductBucket",
    "ProductCount",
    "ProductMapping",
    "ProjectEntitiesResponse",
    "ProjectEntityExistsResponseData",
    "ProjectEntityIdResponse",
    "ProjectEntityMatchResponse",
    "ProjectEntityResponse",
    "ProjectEntitySupplyChainSummaryResponse",
    "ProjectEntitySupplyChainSummaryResponseData",
    "ProjectEntitySupplyChainUpstream",
    "ProjectRiskFactor",
    "ResolutionAttributes",
    "ResolutionProfile",
    "RiskCategoriesSummary",
    "SaveProjectEntityBody",
    "SingleProjectEntityResponse",
    "SourceField",
    "SpecialFacetBucket",
    "SpecialFacetsResponse",
    "StringOrNumber",
    "TagResponse",
    "TradeCounts",
    "Translation",
    "UpdateEntityTagsResponse",
    "UpdateProjectEntityTagsBody",
    "UpstreamCount",
    "UpstreamInfo",
]



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
from ...generated_types.types.identifier_type import IdentifierType
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import typing
import pydantic


class OntologyIdentifier(UniversalBaseModel):
    id: IdentifierType
    label: str
    comment: str
    regex: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import pydantic
import typing
from .trade_traversal_path_segment import TradeTraversalPathSegment
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class TradeTraversalPath(UniversalBaseModel):
    source_entity_id: str = pydantic.Field()
    """
    Root entity ID
    """

    path: typing.List[TradeTraversalPathSegment] = pydantic.Field()
    """
    Upstream paths beginning with the T1-T2 edge
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
